pygeodesy.ecef.EcefMatrix

Package pygeodesy :: Module ecef :: Class EcefMatrix |
[frames] | no frames]

# Class EcefMatrix

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       EcefMatrix

A rotation matrix known as East-North-Up (ENU) to ECEF.

See Also: From ENU to ECEF and Issue #74.

Instance Methods
column(self, column) Get this matrix' `column` 0, 1 or 2 as `3-tuple`. |
copy(self, **unused) Make a shallow or deep copy of this instance. |
__deepcopy__(self, **unused) Make a shallow or deep copy of this instance. |
__copy__(self, **unused) Make a shallow or deep copy of this instance. |
multiply(self, other) Matrix multiply M0' ⋅ M this matrix Transposed with an other matrix. |
rotate(self, xyz, *xyz0) Forward rotation M0' ⋅ ([x, y, z] - [x0, y0, z0])'. |
row(self, row) Get this matrix' `row` 0, 1 or 2 as `3-tuple`. |
unrotate(self, xyz, *xyz0) Inverse rotation [x0, y0, z0] + M0 ⋅ [x,y,z]'. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, sa, ca, sb, cb, *_more, **name) New EcefMatrix matrix. |

Properties
| matrix3 Get this matrix' rows (`3-tuple` of 3 `3-tuple`s).
| matrixTransposed3 Get this matrix' Transposed rows (`3-tuple` of 3 `3-tuple`s).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, sa, ca, sb, cb, *_more, **name) Static Method |
New EcefMatrix matrix. Arguments: `sa` - `sin(phi)` (`float`). `ca` - `cos(phi)` (`float`). `sb` - `sin(lambda)` (`float`). `cb` - `cos(lambda)` (`float`). `_more` - (INTERNAL) from `.multiply`. Returns: a new object with type S, a subtype of T Raises: `EcefError` - If `sa`, `ca`, `sb` or `cb` outside [-1.0, +1.0]. Overrides: object.__new__

### copy (self, **unused) |
Make a shallow or deep copy of this instance. Arguments: `deep` - If `True`, make a deep, otherwise a shallow copy (`bool`). `name` - Optional, non-empty `name=NN` (`str`). Returns: The copy (`This class` or subclass thereof). Overrides: named._Named.copy

### __deepcopy__ (self, **unused) |
Make a shallow or deep copy of this instance. Arguments: `deep` - If `True`, make a deep, otherwise a shallow copy (`bool`). `name` - Optional, non-empty `name=NN` (`str`). Returns: The copy (`This class` or subclass thereof).

### __copy__ (self, **unused) |
Make a shallow or deep copy of this instance. Arguments: `deep` - If `True`, make a deep, otherwise a shallow copy (`bool`). `name` - Optional, non-empty `name=NN` (`str`). Returns: The copy (`This class` or subclass thereof).

### multiply (self, other) |
Matrix multiply M0' ⋅ M this matrix Transposed with an other matrix. Arguments: `other` - The other matrix (EcefMatrix). Returns: The matrix product (EcefMatrix). Raises: `TypeError` - If `other` is not an EcefMatrix.

### rotate (self, xyz, *xyz0) |
Forward rotation M0' ⋅ ([x, y, z] - [x0, y0, z0])'. Arguments: `xyz` - Local `(x, y, z)` coordinates (`3-tuple`). `xyz0` - Optional, local `(x0, y0, z0)` origin (`3-tuple`). Returns: Rotated `(x, y, z)` location (`3-tuple`). Raises: `LenError` - Unequal `len(xyz)` and `len(xyz0)`.

### unrotate (self, xyz, *xyz0) |
Inverse rotation [x0, y0, z0] + M0 ⋅ [x,y,z]'. Arguments: `xyz` - Local `(x, y, z)` coordinates (`3-tuple`). `xyz0` - Optional, local `(x0, y0, z0)` origin (`3-tuple`). Returns: Unrotated `(x, y, z)` location (`3-tuple`). Raises: `LenError` - Unequal `len(xyz)` and `len(xyz0)`.

Property Details

### matrix3 Get this matrix' rows (`3-tuple` of 3 `3-tuple`s). Get method: matrix3(self) - Get this matrix' rows (`3-tuple` of 3 `3-tuple`s). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### matrixTransposed3 Get this matrix' Transposed rows (`3-tuple` of 3 `3-tuple`s). Get method: matrixTransposed3(self) - Get this matrix' Transposed rows (`3-tuple` of 3 `3-tuple`s). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.